@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-## Copyright 2008-2012 Luc Saffre
+## Copyright 2008-2013 Luc Saffre
 ## This file is part of the Lino project.
 ## Lino is free software; you can redistribute it and/or modify 
 ## it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@ has a certain :class:`Property`.
 "Property owner" can be anything: 
 a person, a company, a product, an upload, 
 it depends on the implentation of :class:`PropOccurence`.
-For example :mod:`lino.apps.pcsw.models.PersonProperty`.
+For example :mod:`lino.projects.pcsw.models.PersonProperty`.
 
 A :class:`Property` defines the configuration of a property.
 
@@ -52,7 +52,7 @@ from lino import mixins
 #~ from lino import fields
 from lino.utils.choosers import chooser
 
-from lino.utils.choicelists import get_choicelist, choicelist_choices
+from lino.core.choicelists import get_choicelist, choicelist_choices
 
 MULTIPLE_VALUES_SEP = ','
 
@@ -61,7 +61,7 @@ class DoYouLike(dd.ChoiceList):
     """
     A list of possible answers to questions of type "How much do you like ...?".
     """
-    label = _("certainly not...very much")
+    verbose_name = _("certainly not...very much")
     
 add = DoYouLike.add_item
 add('0',_("certainly not"))
@@ -78,10 +78,10 @@ class HowWell(dd.ChoiceList):
     which are stored in the database as '0' to '4',
     and whose `__unicode__()` returns their translated text.
 
-    `lino.apps.pcsw.models.Languageknowledge.spoken` 
-    `lino.apps.pcsw.models.Languageknowledge.written` 
+    `lino.projects.pcsw.models.Languageknowledge.spoken` 
+    `lino.projects.pcsw.models.Languageknowledge.written` 
     """
-    label = _("not at all...very well")
+    verbose_name = _("not at all...very well")
     
 add = HowWell.add_item
 add('0',_("not at all"))
@@ -234,9 +234,9 @@ class PropertyOccurence(dd.Model):
     A Property Occurence is when a Property occurs, possibly having a certain value.
     
     Abstract base class for 
-    | :class:`lino.apps.pcsw.models.PersonProperty`,
-    | :class:`lino.apps.pcsw.models.WantedProperty`, 
-    | :class:`lino.apps.pcsw.models.AvoidedProperty`,
+    | :class:`lino_welfare.modlib.cv.models.PersonProperty`,
+    | :class:`lino_welfare.modlib.cv.models.WantedProperty`,
+    | :class:`lino_welfare.modlib.cv.models.AvoidedProperty`,
     | ...
     
     """
@@ -332,7 +332,7 @@ class ChoicesByType(PropChoices):
     column_names = 'value text *'
     
 
-def setup_config_menu(site,ui,user,m): 
+def setup_config_menu(site,ui,profile,m): 
     m = m.add_menu("props",_("Properties"))
     m.add_action(PropGroups)
     m.add_action(PropTypes)
